=== modified file 'bzrlib/tests/intertree_implementations/__init__.py'
--- bzrlib/tests/intertree_implementations/__init__.py	2008-04-28 08:57:45 +0000
+++ bzrlib/tests/intertree_implementations/__init__.py	2008-07-23 21:59:19 +0000
@@ -24,6 +24,7 @@
 
 import bzrlib.errors as errors
 from bzrlib.transport import get_transport
+from bzrlib.transform import TransformPreview
 from bzrlib.tests import (
                           adapt_modules,
                           default_transport,
@@ -92,6 +93,9 @@
             result.append(scenario)
         return result
 
+def mutable_trees_to_preview_trees(source, target):
+    preview = TransformPreview(target)
+    return source, preview.get_preview_tree()
 
 def load_tests(basic_tests, module, loader):
     result = loader.suiteClass()
@@ -112,6 +116,13 @@
              optimiser._matching_from_tree_format,
              optimiser._matching_to_tree_format,
              optimiser._test_mutable_trees_to_test_trees))
+
+    # test PreviewTree
+    test_intertree_permutations.append(
+        (InterTree,
+         default_tree_format,
+         default_tree_format,
+         mutable_trees_to_preview_trees))
     adapter = InterTreeTestProviderAdapter(
         default_transport,
         # None here will cause a readonly decorator to be created

=== modified file 'bzrlib/tests/intertree_implementations/test_compare.py'
--- bzrlib/tests/intertree_implementations/test_compare.py	2008-03-07 14:25:46 +0000
+++ bzrlib/tests/intertree_implementations/test_compare.py	2008-07-23 21:59:19 +0000
@@ -432,8 +432,8 @@
         self.assertEqual([], self.do_iter_changes(tree1, tree2))
 
     def added(self, tree, file_id):
-        entry = tree.inventory[file_id]
-        path = tree.id2path(file_id)
+        iterator = tree.iter_entries_by_dir(specific_file_ids=[file_id])
+        path, entry = iterator.next()
         return (file_id, (None, path), True, (False, True), (None, entry.parent_id),
                 (None, entry.name), (None, entry.kind),
                 (None, entry.executable))

=== modified file 'bzrlib/tree.py'
--- bzrlib/tree.py	2008-07-03 13:28:50 +0000
+++ bzrlib/tree.py	2008-07-23 21:59:19 +0000
@@ -836,10 +836,10 @@
         else:
             all_unversioned = deque()
         to_paths = {}
-        from_entries_by_dir = list(self.source.inventory.iter_entries_by_dir(
+        from_entries_by_dir = list(self.source.iter_entries_by_dir(
             specific_file_ids=specific_file_ids))
         from_data = dict((e.file_id, (p, e)) for p, e in from_entries_by_dir)
-        to_entries_by_dir = list(self.target.inventory.iter_entries_by_dir(
+        to_entries_by_dir = list(self.target.iter_entries_by_dir(
             specific_file_ids=specific_file_ids))
         num_entries = len(from_entries_by_dir) + len(to_entries_by_dir)
         entry_count = 0
@@ -937,7 +937,7 @@
             if file_id in to_paths:
                 # already returned
                 continue
-            if not file_id in self.target.inventory:
+            if not file_id in self.target.all_file_ids():
                 # common case - paths we have not emitted are not present in
                 # target.
                 to_path = None

